@@ -1,15 +1,22 @@
-import json
 import logging
 
+import borgmatic.actions.arguments
+import borgmatic.actions.json
 import borgmatic.borg.info
-import borgmatic.borg.rlist
+import borgmatic.borg.repo_list
 import borgmatic.config.validate
 
 logger = logging.getLogger(__name__)
 
 
 def run_info(
-    repository, storage, local_borg_version, info_arguments, local_path, remote_path,
+    repository,
+    config,
+    local_borg_version,
+    info_arguments,
+    global_arguments,
+    local_path,
+    remote_path,
 ):
     '''
     Run the "info" action for the given repository and archive.
@@ -19,23 +26,27 @@ def run_info(
     if info_arguments.repository is None or borgmatic.config.validate.repositories_match(
         repository, info_arguments.repository
     ):
-        if not info_arguments.json:  # pragma: nocover
-            logger.answer(f'{repository["path"]}: Displaying archive summary information')
-        info_arguments.archive = borgmatic.borg.rlist.resolve_archive_name(
+        if not info_arguments.json:
+            logger.answer(
+                f'{repository.get("label", repository["path"])}: Displaying archive summary information'
+            )
+        archive_name = borgmatic.borg.repo_list.resolve_archive_name(
             repository['path'],
             info_arguments.archive,
-            storage,
+            config,
             local_borg_version,
+            global_arguments,
             local_path,
             remote_path,
         )
         json_output = borgmatic.borg.info.display_archives_info(
             repository['path'],
-            storage,
+            config,
             local_borg_version,
-            info_arguments=info_arguments,
-            local_path=local_path,
-            remote_path=remote_path,
+            borgmatic.actions.arguments.update_arguments(info_arguments, archive=archive_name),
+            global_arguments,
+            local_path,
+            remote_path,
         )
-        if json_output:  # pragma: nocover
-            yield json.loads(json_output)
+        if json_output:
+            yield borgmatic.actions.json.parse_json(json_output, repository.get('label'))
